/*
 * Copyright (c) 2011-2013 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.2

TabbedPane {
    
    id: tabbedPane
    objectName: "m_tabbedPane"
    activeTab: scanFilesTab    
    showTabsOnActionBar: false    
    
    onCreationCompleted: {
        // Lock device orientation to portrait on startup
        if (!_app.openedAsCard())
        	OrientationSupport.supportedDisplayOrientation = SupportedDisplayOrientation.DisplayPortrait;  
    }

	// This enables to discard a sheet by swiping right in the sheet
	// I use onPeekStarted and onPeekEnded because sometimes the onPeekStarted signal
	// is not emitted if the peek was too slow.
    onPeekStarted: {
        settingsSheet.close()
        statsSheet.close()
        helpSheet.close()
        logSheet.close()
    }
    onPeekEnded: {
        settingsSheet.close()
        statsSheet.close()
        helpSheet.close()
        logSheet.close()
    }
    
    Menu.definition: MenuDefinition {
        // Info | Options | Help
        actions: [
            ActionItem {                    
                title: qsTr("Info") + Retranslate.onLocaleOrLanguageChanged
                imageSource: "images/ico/a_stats.png"                   
                shortcuts: [ Shortcut { key: "I" }, Shortcut { key: "i" }]
                onTriggered: {
                    _app.setStatsLabelText("");
                    statsSheet.open();
                }
            },
            ActionItem {
                title: qsTr("Options") + Retranslate.onLocaleOrLanguageChanged
                imageSource: "images/ico/a_option.png"                    
                shortcuts: [ Shortcut { key: "O" }, Shortcut { key: "o" }]
                onTriggered: {
                    settingsSheet.open();
                }
            },
            ActionItem {
                title: qsTr("Help") + Retranslate.onLocaleOrLanguageChanged
                imageSource: "images/ico/a_help.png"                                   
                shortcuts: [ Shortcut { key: "H" }, Shortcut { key: "h" }, Shortcut { key: "?" }]
                onTriggered: {
                    helpSheet.open();
                }
            },
            ActionItem {
                title: qsTr("Log") + Retranslate.onLocaleOrLanguageChanged
                imageSource: "images/ico/a_log.png"
                shortcuts: [ Shortcut { key: "L" }, Shortcut { key: "l" }]
                onTriggered: {
                    logSheet.logText = _logger.getLog();
                    logSheet.open();
                }
            }
        ]
    }

    attachedObjects: [        
        ComponentDefinition {
            id: menu
        },
        // Definition of the second Page, used to dynamically create the Sheet inside the QML.
        HelpSheet {
        	id: helpSheet            
        },
        SettingsSheet {
            id: settingsSheet
        },
        StatsSheet {
            id: statsSheet
        },
        LogSheet {
            id: logSheet
        }
    ]
    
    Tab {
        title: qsTr("Scan Files") + Retranslate.onLocaleOrLanguageChanged
        id: scanFilesTab
        objectName: "m_scanPageTab"
        shortcuts: [ Shortcut { key: "S" }, Shortcut { key: "s" }]        
        imageSource: "images/ico/a_scan.png"
        
        delegate: Delegate {
            id: scanPage
            source: "scanPage.qml"
        }
        delegateActivationPolicy: TabDelegateActivationPolicy.Default
    }    
    Tab {
        title: qsTr("Update") + Retranslate.onLocaleOrLanguageChanged
        id: updateTab
        objectName: "m_updateTab"
        shortcuts: [ Shortcut { key: "S" }, Shortcut { key: "s" }]        
        imageSource: "images/ico/a_update.png"
        
        delegate: Delegate {
            id: updatePage
            source: "updatePage.qml"
        }
        delegateActivationPolicy: TabDelegateActivationPolicy.Default
    } 
    Tab {
        title: qsTr("Quarantine") + Retranslate.onLocaleOrLanguageChanged
        id: quarantineTab
        objectName: "m_quarantineTab"
        shortcuts: [ Shortcut { key: "S" }, Shortcut { key: "s" }]        
        imageSource: "images/ico/a_quar.png"
        
        delegate: Delegate {
            id: quarantinePage
            source: "quarantinePage.qml"            
        }
        delegateActivationPolicy: TabDelegateActivationPolicy.Default
    }     
}
