import bb.cascades 1.2
import bb.system 1.0

Page {
    titleBar: TitleBar {
        // Localized text with the dynamic translation and locale updates support
        title: qsTr("Secure AntiVirus Pro") + Retranslate.onLocaleOrLanguageChanged
    }
    
    Container {
        layout: DockLayout {
        }
        
        ImageView {
            imageSource: "asset:///images/ico/s_icon.png"
            maxHeight: 75.0
            preferredHeight: 75.0
            minHeight: 75.0
            minWidth: 75.0
            preferredWidth: 75.0
            maxWidth: 75.0
            translationX: 50.0
            translationY: 30.0
            accessibility.name: ""
            accessibility.description: "Logo"
        }
        Label {
            text: qsTr("Scan for Threats") + Retranslate.onLocaleOrLanguageChanged
            translationX: 150.0
            translationY: 50.0
            textStyle.fontWeight: FontWeight.Bold
            textFit.maxFontSizeValue: 8.0
            textFit.minFontSizeValue: 8.0
        }
        Button {
            id: startScanButton
            text: _app.startButtonText
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Top
            translationY: 150.0
            scaleX: 1.0
            minWidth: 700.0
            preferredWidth: 700.0
            maxWidth: 700.0
            onClicked: {
                _app.startScan("allFiles");
            }
        }
        Button {
            id: updateDefinitionsButton
            text: qsTr("Update Definitions") + Retranslate.onLocaleOrLanguageChanged
            objectName: "m_updateDefinitionsButton"
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Top
            translationY: 250.0
            scaleX: 1.0
            minWidth: 700.0
            preferredWidth: 700.0
            maxWidth: 700.0
            onClicked: _app.showUpdateTab()
        }
        ProgressIndicator {
            id: fileIndicator
            value: _app.fileProgress
            translationY: 350.0
            horizontalAlignment: HorizontalAlignment.Center
            accessibility.name: "fileIndicatorAB"
            accessibility.description: "File Indicator"
            toValue: 100.0
        }
        ProgressIndicator {
            id: scanIndicator
            value: _app.scanProgress
            translationY: 375.0
            horizontalAlignment: HorizontalAlignment.Center
            accessibility.name: "scanIndicatorAB"
            accessibility.description: "Scan Indicator"
            toValue: 100.0
        }
        Container {
            rightPadding: 25
            leftPadding: rightPadding
            translationY: 400.0
            Label {
                id: stateLabel
                multiline: true;
                text: _app.stateLabelText
            }
        }
    }
    
    actions: [                            
        // context items
        ActionItem {
            title: qsTr("Share") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "images/ico/a_share.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            shortcuts: [ Shortcut { key: "B" }, Shortcut { key: "b" }]
            
            attachedObjects: [
                Invocation {
                    id: shareQuery
                    query {
                        mimeType: "text/plain"
                        data: qsTr("Secure AntiVirus Pro for BlackBerry 10!  You may not need it, but one day you may be happy you have it.  Get it here: http://appworld.blackberry.com/webstore/content/34092890") + Retranslate.onLocaleOrLanguageChanged      
                    }
                }
            ]
            
            onTriggered: {
                shareQuery.trigger("bb.action.SHARE")
            }   
        }
        ,
        ActionItem {
            title: qsTr("Report Bug") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "images/ico/a_bug.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            shortcuts: [ Shortcut { key: "R" }, Shortcut { key: "r" }]
            
            attachedObjects: [
                SystemDialog {
                    id: bugDialog
                    title: qsTr("Report Bug") + Retranslate.onLocaleOrLanguageChanged
                    body: qsTr("When reporting a bug, please include:  Any steps you remember to reproduce the bug, what you expected to happen, and what REALLY happened!") + Retranslate.onLocaleOrLanguageChanged              
                    
                    onFinished: {
                        if (bugDialog.result == SystemUiResult.ConfirmButtonSelection) {
                            bugQuery.trigger("bb.action.SENDEMAIL");
                        }
                    }
                },
                Invocation {
                    id: bugQuery
                    query {
                        mimeType: "text/plain"
                        invokeTargetId: "sys.pim.uib.email.hybridcomposer"
                        uri: "mailto:support@filearchivehaven.com?subject=Bug%20Report%20SecureAntiVirusPro%20" + Application.applicationVersion
                    }                   
                }
            ]
            
            onTriggered: {
                bugDialog.show();
            }
        },
        
        ActionItem {
            title: qsTr("Known Bugs") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "images/ico/a_bugn.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            shortcuts: [ Shortcut { key: "K" }, Shortcut { key: "K" }]
                      
            onTriggered: {
                _downloadManager.getBugsOnline("http://www.filearchivehaven.com/data/AV3/bugs")
            }
        },
        
        ActionItem {
            title: qsTr("Write Review") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "images/ico/a_review.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            shortcuts: [ Shortcut { key: "W" }, Shortcut { key: "w" }]        
            
            attachedObjects: [
                SystemDialog {
                    id: reviewDialog
                    title: qsTr("Leave Review") + Retranslate.onLocaleOrLanguageChanged
                    body: qsTr("I need your help to keep making this application great!  If you experience any issues, please try contacting me before leaving a negative review (so I can fix the problem).  Please be honest in your review, but keep in mind that positive reviews means more users (and ultimately more improvements).") + Retranslate.onLocaleOrLanguageChanged 
                    onFinished: {
                        if (reviewDialog.result == SystemUiResult.ConfirmButtonSelection) {
                            reviewQuery.trigger("bb.action.OPEN")
                        }
                    }
                },
                Invocation {
                    id: reviewQuery
                    query {
                        mimeType: "text/html"
                        invokeTargetId:  "sys.appworld"
                        uri: "appworld://content/34092890"
                    }                   
                }
            ]
            
            onTriggered: {
                reviewDialog.show()
            }
        }
    ]
}